@@ -7,7 +7,8 @@ import numpy as np
 from .utils import readToGray
 from .utils import saveNumpy
 
-def preprocess(DIR, categories, resized_size, size, name, isSave=True):
+# def preprocess(DIR, categories, resized_size=None, train_size, name, isSave=True):
+def preprocess(DIR, categories, resized_size=None, train_size, name):
     """
     Reads Images in base directory DIR
     Returns
@@ -24,31 +25,36 @@ def preprocess(DIR, categories, resized_size, size, name, isSave=True):
         print('[INFO] Loading from Numpy Files')
     except:
         print(f'[INFO] Could not find {name}.npy. Generating the Image Files')
-        for category in categories:
-            category_path = os.path.join(DIR, category)
-            classNum = categories.index(category)
+
+        if train_size == None:
+            train_size = len(os.listdir(os.path.join(DIR, classes[0])))
+
+        for item in classes:
+            class_path = os.path.join(DIR, item)
+            classNum = classes.index(item)
             count = 0 
-            for image in os.listdir(category_path):
+            for image in os.listdir(class_path):
                 if count != size:
-                    image_path = os.path.join(category_path, image)
+                    image_path = os.path.join(class_path, image)
                     # Returns image RESIZED and GRAY
                     gray = readToGray(image_path, resized_size)
 
                     train.append([gray, classNum])
                     count +=1 
-                    _printTotal(count)
+                    print(f'{_printTotal(count)} - {item}')
                 else:
                     break
+
         # Shuffling the Training Set
         train = shuffle(train)
 
-        # Converting to Numpy
-        train = np.array(train)
+        # # Converting to Numpy
+        # train = np.array(train)
 
-        # Saves the Train set as a .npy file
-        if isSave == True:
-            #Converts to Numpy and saves
-            saveNumpy(name, train)
+        # # Saves the Train set as a .npy file
+        # if isSave == True:
+        #     #Converts to Numpy and saves
+        #     saveNumpy(name, train)
 
     #Returns Training Set
     return train
@@ -91,5 +97,4 @@ def normalize(x):
     Normalizes the data to mean 0 and standard deviation 1
     """
     x = x/255.0
-    return x
-    
\ No newline at end of file
+    return x
\ No newline at end of file
